/*
 * COPYRIGHT 2016 YOSPACE TECHNOLOGIES LTD. ALL RIGHTS RESERVED.
 */

#import <Foundation/Foundation.h>

/** The YPPolicyHandling protocol declares a set of methods to provide playback policy to clients.<br/>
    It is implemented by a policy plugin and policy calls to the Yospace Session Manager are delegated to this plugin.
 */
@protocol YPPolicyHandling <NSObject>

/** Returns to the client whether playback can start.
 
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if playback can start, NO otherwise.
 @since from 1.0
 */
- (BOOL) canStart:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether playback can stop.
 
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if playback can stop, NO otherwise.
 @since from 1.0
 */
- (BOOL) canStop:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether playback can pause.
 
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if playback can pause, NO otherwise.
 @since from 1.0
 */
- (BOOL) canPause:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether playback can seek from the current playhead position.
 
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if playback can seek, NO otherwise.
 @since from 1.0
 */
- (BOOL) canSeek:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client the playhead position that the user can seek to.
 
 @param position the playhead position that the user wishes to seek to
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return the actual playhead position that the user can seek to, based on the implemented policy.
 @since from 1.0
 */
- (NSTimeInterval) willSeekTo:(NSTimeInterval)position timeline:(NSArray*)timeline;

/** Returns to the client whether volume can be muted.
 
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if volume can be muted, NO otherwise.
 @since from 1.0
 */
- (BOOL) canMute:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether full screen mode can change.
 
 @param fullScreen The target full screen mode
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if full screen mode can change, NO otherwise.
 @since from 1.0
 */
- (BOOL) canChangeFullScreenMode:(BOOL)fullScreen playhead:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether a currently-displayed non-linear creative can be expanded.
 
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if the creative can be expanded, NO otherwise.
 @since from 1.0
 */
- (BOOL) canExpandCreative:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether the user can click-through.
 
 @param url The click-through Url.
 @param playhead The current playhead position
 @param timeline The stream timeline represented as an array of YSAdBreak objects
 @return YES if the user can click through, NO otherwise.
 @since from 1.0
 */
- (BOOL) canClickThrough:(NSURL*)url playhead:(NSTimeInterval)playhead timeline:(NSArray*)timeline;

/** Returns to the client whether to fetch and load non-linear creative graphical elements from any VAST received from the ad server.
 If true the graphical elements will be available to retrieve from the SDK at the point an advert starts.
 If false then the client must fetch any remote resources itself, which may delay their display.
 
 @return YES if the SDK should pre-load graphical elements.
 @since from 1.0
 */
@property (NS_NONATOMIC_IOSONLY, readonly) BOOL shouldPreloadNonLinearGraphicalElements;

/** Returns to the client whether to fetch and load non-linear iFrame resource elements from any VAST received from the ad server.
 If true the iFrame elements will be available to retrieve from the SDK at the point an advert starts.
 If false then the client must fetch any remote resources itself, which may delay their display.
 
 @return YES if the SDK should pre-load iFrame resource elements.
 @since from 1.2
 */
@property (NS_NONATOMIC_IOSONLY, readonly) BOOL shouldPreloadIFrameResourceElements;

@end
